<?php

namespace Drupal\acquia_perz\Controller;

use Drupal\acquia_perz\ClientFactory;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Routing\Access\AccessInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Implements permission to prevent unauthorized access to webhooks.
 */
class HmacValidationController implements AccessInterface {

  /**
   * Logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;

  /**
   * Content Hub Client Manager.
   *
   * @var \Drupal\acquia_perz\ClientFactory
   */
  protected $clientFactory;

  /**
   * Constructs a ContentHubAccess object.
   *
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger factory.
   * @param \Drupal\acquia_perz\ClientFactory $client_factory
   *   The client factory.
   */
  public function __construct(LoggerChannelFactoryInterface $logger_factory, ClientFactory $client_factory) {
    $this->loggerFactory = $logger_factory;
    $this->clientFactory = $client_factory;
  }

  /**
   * Checks access to Entity CDF.
   *
   * Only grants access to logged in users with 'Administer Acquia Content Hub'
   * permission or if the request verifies its HMAC signature.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The HTTP request object.
   *
   * @return \Drupal\Core\Access\AccessResult
   *   TRUE if granted access, FALSE otherwise.
   */
  public function access(Request $request) {
    // Only allow access if the Signature validates.
    $referer = $request->headers->get('referer');
    $host = $request->getSchemeAndHttpHost();
    if ($referer === $host . '/admin/config/graphql/servers/manage/perz/explorer') {
      return AccessResult::allowed();
    }
    $validateSignature = $this->clientFactory->authenticate($request);
    return AccessResult::allowedIf((bool) $validateSignature);
  }

}
